@@ -56,22 +56,16 @@ public class Action extends GObject {
 	/**
 	 * Construct a new Action object.
 	 */
-	public Action() {
-		if (-1 != handle)
-			handle = allocate();
+	public Action(String name, String label, String tooltip, String stockId) {
+		handle = gtk_action_new(name, label, tooltip, stockId);
 	}
 	
+	protected Action() {}
+	
 	Action(int handle) {
 		this.handle = handle;
 	}
 	
-	/* (non-Javadoc)
-	 * @see java.lang.Object#finalize()
-	 */
-	protected void finalize() throws Throwable {
-		free(handle);
-	}
-
 	/**
 	 * Returns the name of the action.
 	 * @return the name of the action
@@ -167,7 +161,15 @@ public class Action extends GObject {
 	public void disconnectAccelerator() {
 		gtk_action_disconnect_accelerator(handle);
 	}
+
+	public boolean isSensitive() {
+		return gtk_action_is_sensitive(handle);
+	}
 	
+	public boolean isVisible() {
+		return gtk_action_is_visible(handle);
+	}
+
 	/**
 	 * Retrieve the runtime type used by the GLib library.
 	 */
@@ -179,6 +181,7 @@ public class Action extends GObject {
 	 * BEGINNING OF JNI CODE
 	 ****************************************/
 	native static final protected int gtk_action_get_type ();
+	native static final protected int gtk_action_new(String name, String label, String tooltip, String stockId);
 	native static final protected String gtk_action_get_name(int action);
 	native static final protected void gtk_action_activate(int action);
 	native static final protected int gtk_action_create_icon(int action, int iconSize);
@@ -189,8 +192,10 @@ public class Action extends GObject {
 	native static final protected int[] gtk_action_get_proxies(int action);
 	native static final protected void gtk_action_connect_accelerator(int action);
 	native static final protected void gtk_action_disconnect_accelerator(int action);
-	native static protected int allocate();
-	native static protected void free(int action);
+	native static final protected boolean gtk_action_is_sensitive(int action);
+	native static final protected boolean gtk_action_get_sensitive(int action);
+	native static final protected boolean gtk_action_is_visible(int action);
+	native static final protected boolean gtk_action_get_visible(int action);
 	/****************************************
 	 * END OF JNI CODE
 	 ****************************************/
